@@ -9,10 +9,11 @@ __all__ = [
     'http',
     'io',
     'mqtt',
-    's3'
+    's3',
+    'websocket',
 ]
 
-__version__ = '0.15.3'
+__version__ = '0.16.11'
 
 
 class NativeResource:
